#ifndef AK_CERTIFICATE_GENERATOR_HPP
#define AK_CERTIFICATE_GENERATOR_HPP

#include "ref_ptr.hpp"
#include "CertificateGeneratorImpl.hpp"

namespace Akenti {

/**
  * A <i>CertificateGenerator<i> object is a <i>reference-count</i> pointer
  * that wraps a <i>CertificateGeneratorImpl</i> object. It provides
  * applications, albeit indirectly, the methods to set the fields of a 
  * certificate and then to generate a certificate. A certificate is a 
  * constant object that can not be changed once it has been created.
  *
  * @see ref_ptr
  * @see CertificateGeneratorImpl
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  **/

class CertificateGenerator : public ref_ptr<CertificateGeneratorImpl> {

public:

  /**
    * Constructs a <i>CertificateGenerator</i> given a 
    * <i>CertificateGeneratorImpl</i> object.
    *
    * @param impl  wrapped <i>CertificateGeneratorImpl</i> object
    * @see ref_ptr
    * @see CertificateGeneratorImpl
    */
  CertificateGenerator(CertificateGeneratorImpl* impl) 
    : ref_ptr<CertificateGeneratorImpl>(impl) {
  }
  
  /**
    * Decrements the count of references to the wrapped 
    * <i>CertificateRequestImpl</i> object. If this count is zero, 
    * then the wrapped object is deleted.
    *
    * @see ref_ptr
    */
  ~CertificateGenerator() {
  }

};

} // end of namespace Akenti

#endif
