#ifndef AK_CERTIFICATE_REQUEST_HPP
#define AK_CERTIFICATE_REQUEST_HPP

#include "ref_ptr.hpp"
#include "CertificateRequestImpl.hpp"

namespace Akenti {

/**
  * A <i> CertificateRequest</i> object is a <b>reference-count</b>
  * pointer that wraps a <i>CertificateRequestImpl</i>
  *
  * @see ref_ptr
  * @see CertificateImpl
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */ 

class CertificateRequest : public ref_ptr<CertificateRequestImpl> {

public:

  /**
    * Constructs a <i>CertificateRequest</i> given a 
    * <i>CertificateRequestImpl</i> object.
    *
    * @param impl  wrapped <i>CertificateRequestImpl</i> object
    * @see ref_ptr
    * @see CertificateRequestImpl
    */
  CertificateRequest(CertificateRequestImpl *impl = NULL) 
    : ref_ptr<CertificateRequestImpl> (impl){
  }

  /**
    * Decrements the count of references to the wrapped 
    * <i>CertificateRequestImpl</i> object. If this count is zero, 
    * then the wrapped object is deleted.
    *
    * @see ref_ptr
    */
  ~CertificateRequest() {
  }

};

} // end of namespace Akenti

#endif
