/* -*-C++-*- */
#ifndef _NETLOGGER_H_
#define _NETLOGGER_H_

#include <string>
#include "logging.h"

class NetLogger
{
 public:
  
/* constructor */ 
    NetLogger();

/* Open handle for output.
 *
 * Flags for NetLoggerOpen:
 *    NL_ENV    - Check environment variable for log dest.
 *    NL_MEM    - Buffer to memory
 *    NL_APPEND - Append to file instead of overwrite
 */
    /* open by url. formats: 
     *   file://<filename> (local file)
     *   x-netlog://<host>:<port> (netlogd)
     *   x-syslog:// (syslog)
     */
    void open(const std::string& progName, const std::string& url, int flags);
    /* open by file descriptor */
    void open(const std::string& progName, int fd, int flags );

/* Set the logging level. Level 0, the default, means "write all".
 * If !=0, write()s with a level that is greater than this level 
 * will return immediately.
 */
    void setLevel(int lvl);

/* Write a NetLogger message */   
    void write(const std::string& keyword, const std::string& mesg);
    
/* Write a NetLogger message with user-provided timestamp */
    void write(const std::string& keyword, const std::string& mesg, 
	       long sec, long usec);
/* Write a NetLogger message of a certain 'level' */   
    void write(int lvl, const std::string& keyword, const std::string& mesg);
    
/* Write a NetLogger message of a certain 'level' 
 * with user-provided timestamp */
    void write(int lvl, const std::string& keyword, const std::string& mesg, 
	       long sec, long usec);

    
/* Flush memory-buffered messages 
 * Return: 1=something was flushed; 0=no msgs flushed
 */
    int flush();
    
/* Set a 'tag' to be added to every message
 * in every instance of NetLogger
 * (convenience fn)
 */
    void setTag( const std::string& tag );

/* Flush buffer, close socket/file/syslog */
    void close();

/* Get the host name */
    std::string getHostName();

/* Get the file name */
    std::string getFileName();

/* Get the file descriptor */
    int getFd();

/* Get the current logging level */
    int getLevel();

  private:

    NLhandle* mHandle_p; // Handle used in calls to C API

};

#endif  //  _NETLOGGER_H_
