#ifndef AKENTI_POLICY_INFO_HPP
#define AKENTI_POLICY_INFO_HPP

#include <vector>
#include "Xerces-Decls.hpp"
#include "CertificateInfo.hpp"

using std::vector;

namespace Akenti {

/**
  * Holds a list of <i>CertificateResponse</i>s.
  *
  * @see CertificateResponse
  */
class PolicyInfo {

public:

  /** 
    * Default constructor.
    */
  PolicyInfo();

  /** 
    * Sets the <i>CertificateInfo<i>.
    */
  void setCertificateInfos(const vector<CertificateInfo>& certInfos);

  /** 
    * Returns the vector of <i>CertificateInfo</i>.
    */
  const vector<CertificateInfo>& getCertificateInfos() const;

  /** 
    * Sets whether policy is correct.
    */
  void setPolicyCorrect(bool isPolicyCorrect);

  /** 
    * Returns <i>true</i> if policy is correct, false otherwise.
    */
  bool isPolicyCorrect() const;

  /** 
    * Sets the name of the resource.
    */
  void setResource(const string& resource);

  /** 
    * Returns the name of the resource.
    */
  const string& getResource() const;

  /** 
    * Populates the DOMElement from this <i> PolicyInfo</i>.
    */
   void toXML(DOMElement* policyInfo) const;

  /** 
    * Initializes this <i>PolicyInfo</i> from the DOMElement.
    */
   void fromXML(const DOMElement* policyInfo);

private:

  vector<CertificateInfo> certInfos;
  bool policyCorrect;
  string resource;

};

}

#endif
