#ifndef AK_PRIVATE_KEY_HPP
#define AK_PRIVATE_KEY_HPP 

#include "PrivateKeyImpl.hpp"
#include "ref_ptr.hpp"

namespace Akenti {

/**
  * A <i>PrivateKey</i> object is a <b>reference-count</b> pointer
  * that wraps a <i>PrivateKeyImpl</i> object. 
  * 
  * @see ref_ptr
  * @see PrivateKeyImpl
  * @see KeyPair#getPrivateKey()
  * @see KeyFactoryImpl#getKeyEncoded(const string&, const PrivateKey&)
  * @see KeyFactoryImpl#initPrivateKey(const string&, 
  *                                    const string&, const string&)
  * @see KeyFactoryImpl#generateRSAKeyPair(int, unsigned long)
  * @see KeyFactoryImpl#generateDSAKeyPair(int, const string&)
  * @see SignatureImpl#initSign(const PrivateKey&)
  *
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  **/

class PrivateKey : public ref_ptr<PrivateKeyImpl> {

public:

  /**
    * Constructs a <i>PrivateKey</i> given a <i>PrivatekeyImpl</i>
    * object. Typically a <i>KeyFactory</i> is used to create an instance of
    * this class. 
    *
    * @param impl wrapped <i>PrivateKeyImpl</i> object. 
    * @see PrivateKeyImpl
    * @see ref_ptr 
    * @see KeyFactoryImpl#initPrivateKey(const string&, 
    *                                    const string&, 
    *                                    const string&)
    * @see KeyFactoryImpl#generateRSAKeyPair(int, unsigned long)
    * @see KeyFactoryImpl#generateDSAKeyPair(int, const string&)
    * @see KeyPair#getPrivateKey()
    */
  PrivateKey(PrivateKeyImpl* impl = NULL)
    : ref_ptr<PrivateKeyImpl> (impl) {
  }

  /**
    * Decrements the count of references to the wrapped <i>PrivatekeyImpl</i>
    * object. If this count is zero, then the wrapped object is deleted. 
    *
    * @see ref_ptr
    */
  ~PrivateKey() {
  }

};

} // end of namespace Akenti

#endif
