#ifndef USECOND_CERT_GENERATOR_HPP
#define USECOND_CERT_GENERATOR_HPP

#include <vector>
#include "AkentiCertGenerator.hpp"

using std::vector;

namespace Akenti {

class Condition;

/**
  * Used to generate a <i>UseCondition</i> certificate.
  *
  * <PRE>
  * <b>Usage:</b>
  *   AttributeCertGenerator gen;
  *
  *   // first call all set the methods in <i>AkentiCertGenerator</i>
  *   gen.setResource(someResource);
  *   gen.setAttribute("GROUP");
  *   gen.setUseCondition(someUseCondition);
  *   gen.setActions(someActions);
  *   // finally call the sign method in <i>AkentiCertGenerator</i>
  * </PRE>
  *
  * @version 1.1 00/05/25
  * @see AkentiCertGenerator
  * @see UseCondition
  * @see UseCondCertificateImpl 
  * @see AkentiCertificate
  *
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */

class UseCondCertGenerator : public AkentiCertGenerator {

public:

  /**
    * Creates this object.
    */
  UseCondCertGenerator();

  /**
    * Destroys this object.
    */
  ~UseCondCertGenerator();

  /**
    * Sets the resource.
    * 
    * resource the value for the resource 
    */
  void setResource(const string& resource);

  /**
    */
  void setLocalScope(bool isScopeLocal);

  /**
    */
  void setCritical(bool isCritical);

  /**
    * Sets the UseCondition that needs to be satisfied to award the
    * the actions.
    *
    * @see UseCondition
    * @see setActions(const vector<string&);
    * @see UseConditionCertificateImpl
    */
  void setCondition(const Condition& condition);

  /**
    * Sets the actions that will be awarded if the UseCondition 
    * is satisfied.
    *
    * @see setUseCondition(const UseCondition&);
    * @see UseConditionCertificateImpl
    */
  void setActions(const vector<string>& actions);

};

} // end of name space

#endif
