#include <iostream>
#include <string>
#include <unistd.h>
#include "Provider.hpp"
#include "OpenSSLProviderImpl.hpp"
#include <iostream>
#include "Util.hpp"
#include "XMLUtil.hpp"
#include "CertificateRetrievalFactory.hpp"
#include "URL.hpp"
#include "AkentiCertificate.hpp"
#include "MessageDigest.hpp"
#include "URL.hpp"
#include "Exception.hpp"
#include "Error.hpp"

using namespace Akenti;
using namespace std;

/**
  * <pre>
  * <b>FindUC:</b>
  * Use this program to locate Use-Condition certificates.
  * </pre> 
  */

namespace FindUC {

void
printPurpose() {
  cerr << "Purpose: Use this program to locate Use-Condition certs." << endl
       << endl;
}

void
printUsage() {
  cerr << "Usage: FindUC args " << endl 
       << "  -r arg     - resource " << endl
       << "  -u arg     - location in a url format" << endl
       << "  [-v]       - verbose" << endl 
       << "  [-h]       - help" << endl;
}

int
main (int argc, char** argv) {
  string urlString;
  string resource;
  bool verbose = false;
  int opt;

  if (argc < 2) {
    printPurpose();
    printUsage();
    exit(2);
  }

  while ((opt = getopt(argc, argv, "r:u:vh")) != EOF) {
    switch(opt){
      case 'u':
        urlString = optarg;
        break;
      case 'r':
        resource = optarg;
        break;
      case 'v':
        verbose = true;
        break;
      case 'h':
      default:
        printUsage();
        exit(2);
    }
  }

  try {
    if (verbose) {
      cout << "Inializing XML Library ..." << endl;
    }

    XMLUtil::init();

    if (verbose) {
      cout << "Installing security provider ..." << endl;
    }

    Provider provider = Provider(new OpenSSLProviderImpl);
    
    provider->loadDigestAlgorithms();
    Provider::setProvider(provider);

    if (verbose) {
      cout << "Parsing " << urlString << endl;
    }

    URL url;

    try {
      url = urlString;
    } catch(Exception& ex) {
      cerr << "Bad url" << endl;
      exit(2);
    }

    if (resource == "") {
      cerr << "Must provide a resource" << endl;
      exit(2);
    }

    if (verbose) {
      cout << "Resource is " << resource << endl;
    }

    map <string,string> certArgs;

    certArgs["type"] = "UseCondition";
    certArgs["hash"] = Util::createFileName(MessageDigest::digest("MD5", resource));

    if (verbose) {
      cout << "Hash =" << certArgs["hash"] << endl;
    }

    vector<AkentiCertificate> certs = CertificateRetrievalFactory::getAkentiCertificates(
      url,
      certArgs
    );

    int size = certs.size();

    if (verbose) {
      cout << "Found " << size << " Use-Condition certificates" << endl;
    }

    for (int i = 0; i < size; i++) {
      AkentiCertificate::writeToStream("XML", cout, certs[i]);
    }

    exit(!size);
  } catch (Exception& ex) {
    cerr << "Caught exception " << ex.getMessage() << endl;
    exit(2);
  } catch (Error& er) {
    cerr << "Caught error:(Report to Akenti team):" << er.getMessage() <<endl;
    exit(3);
  }
}

}
