#ifndef AKENTI_CACHE_REQUEST_HPP
#define AKENTI_CACHE_REQUEST_HPP

#include "CacheCertificate.hpp"

using std::string;

using namespace Akenti;

namespace Akenti {

class UtcTime;
class OutputStream;
class InputStream;

/**
  * <i>CacheRequest</i> 
  *
  * @see CacheCertificate 
  * @see UtcTime
  * @see OutputStream 
  * @see InputStream
  * 
  * @version 1.1 00/05/01
  * @author Srilekha Mudumbai
  * @author Abdelilah Essiari
  */
class CacheRequest {

public:

  /**
    *
    */
  CacheRequest();

  /**
    * 
    */
  CacheRequest(const string& method);

  /**
    *
    */
  virtual ~CacheRequest();

  /**
    *
    */
  const string& getMethod() const;

  /**
    *
    */
  bool hasMethod(const string& method) const;

  /**
    *
    */
  void setRootResourceName(const string& rootResourceName);

  /**
    *
    */
  const string& getRootResourceName() const;
  
  /**
    *
    */
  void setCertHash(const string& certHash);

  /**
    *
    */
  const string& getCertHash() const;

  /**
    *
    */
  void setDirName(const string& dirName);

  /**
    *
    */
  const string& getDirName() const;

  /**
    *
    */
  void setCertificate(const CacheCertificate& cert);
  
  /**
    *
    */
  const CacheCertificate& getCertificate() const;

  /**
    *
    */
  const UtcTime& getNotAfter() const;

  /**
    *
    */
  void writeExternal(OutputStream& os) const;

  /**
    *
    */
  void readExternal(InputStream& is);

  /**
    *
    */
  string toString() const;

  /**
    *
    */
  virtual string paramString() const;

protected:

  /**
    *
    */
  virtual void writeHeaderInfo(OutputStream& os) const;
  
  /**
    *
    */
  virtual void writeResourceInfo(OutputStream& os) const;

  /**
    *
    */
  virtual void writeCertInfo(OutputStream& os) const;

  /**
    *
    */
  virtual void readHeaderInfo(InputStream& is);
  
  /**
    *
    */
  virtual void readResourceInfo(InputStream& is);

  /**
    *
    */
  virtual void readCertInfo(InputStream& is);

  /**
    *
    */
  string parse(const string& keyword, const string& line) const;

  /**
    *
    */
  string readLine(InputStream& is) const;

private:

  string method;

  string rootResourceName;

  string certHash;

  string dirName;

  CacheCertificate cert;

};

}

#endif

